Struct wasmrs_host::CallContext
source · pub struct CallContext { /* private fields */ }Expand description
A CallContext is a way to bucket calls together with the same memory and configuration.
Implementations
sourceimpl CallContext
impl CallContext
sourcepub fn get_import(&self, namespace: &str, operation: &str) -> Result<u32, Error>
pub fn get_import(&self, namespace: &str, operation: &str) -> Result<u32, Error>
Get the import id for a given namespace and operation.
sourcepub fn get_export(&self, namespace: &str, operation: &str) -> Result<u32, Error>
pub fn get_export(&self, namespace: &str, operation: &str) -> Result<u32, Error>
Get the export id for a given namespace and operation.
sourcepub fn dump_operations(&self)
pub fn dump_operations(&self)
A utility function to dump the operation list.